#line 4 "json-lex.l"
#ifdef HAVE_CONFIG_H
# include <config.h>
#endif



#line 9 "json-lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

/* %not-for-header */

/* %if-c-only */
/* %if-not-reentrant */

/* %endif */
/* %endif */
/* %ok-for-header */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 37
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* %if-c++-only */
/* %endif */

/* %if-c-only */
    
/* %endif */

/* %if-c-only */

/* %endif */

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
/* %if-c-only */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>
/* %endif */

/* %if-tables-serialization */
/* %endif */
/* end standard C headers. */

/* %if-c-or-c++ */
/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* %endif */

/* %if-c++-only */
/* %endif */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define grecs_json_const const
#else
#define grecs_json_const
#endif

/* %not-for-header */

/* Returned upon end-of-file. */
#define YY_NULL 0
/* %ok-for-header */

/* %not-for-header */

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)
/* %ok-for-header */

/* %if-reentrant */
/* %endif */

/* %if-not-reentrant */

/* %endif */

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (grecs_json__start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((grecs_json__start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE grecs_json_restart(grecs_json_in  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(grecs_json__state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct grecs_json__buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t grecs_json__size_t;
#endif

/* %if-not-reentrant */
extern grecs_json__size_t grecs_json_leng;
/* %endif */

/* %if-c-only */
/* %if-not-reentrant */
extern FILE *grecs_json_in, *grecs_json_out;
/* %endif */
/* %endif */

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define grecs_json_less(n) \
	do \
		{ \
		/* Undo effects of setting up grecs_json_text. */ \
        int grecs_json_less_macro_arg = (n); \
        YY_LESS_LINENO(grecs_json_less_macro_arg);\
		*grecs_json__cp = (grecs_json__hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(grecs_json__c_buf_p) = grecs_json__cp = grecs_json__bp + grecs_json_less_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up grecs_json_text again */ \
		} \
	while ( 0 )

#define unput(c) grecs_json_unput( c, (grecs_json_text_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct grecs_json__buffer_state
	{
/* %if-c-only */
	FILE *grecs_json__input_file;
/* %endif */

/* %if-c++-only */
/* %endif */

	char *grecs_json__ch_buf;		/* input buffer */
	char *grecs_json__buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	grecs_json__size_t grecs_json__buf_size;

	/* Number of characters read into grecs_json__ch_buf, not including EOB
	 * characters.
	 */
	grecs_json__size_t grecs_json__n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int grecs_json__is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int grecs_json__is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int grecs_json__at_bol;

    int grecs_json__bs_lineno; /**< The line count. */
    int grecs_json__bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int grecs_json__fill_buffer;

	int grecs_json__buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via grecs_json_restart()), so that the user can continue scanning by
	 * just pointing grecs_json_in at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */

/* %if-not-reentrant */

/* Stack of input buffers. */
static size_t grecs_json__buffer_stack_top = 0; /**< index of top of stack. */
static size_t grecs_json__buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * grecs_json__buffer_stack = 0; /**< Stack as an array. */
/* %endif */
/* %ok-for-header */

/* %endif */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (grecs_json__buffer_stack) \
                          ? (grecs_json__buffer_stack)[(grecs_json__buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (grecs_json__buffer_stack)[(grecs_json__buffer_stack_top)]

/* %if-c-only Standard (non-C++) definition */

/* %if-not-reentrant */
/* %not-for-header */

/* grecs_json__hold_char holds the character lost when grecs_json_text is formed. */
static char grecs_json__hold_char;
static grecs_json__size_t grecs_json__n_chars;		/* number of characters read into grecs_json__ch_buf */
grecs_json__size_t grecs_json_leng;

/* Points to current character in buffer. */
static char *grecs_json__c_buf_p = (char *) 0;
static int grecs_json__init = 0;		/* whether we need to initialize */
static int grecs_json__start = 0;	/* start state number */

/* Flag which is used to allow grecs_json_wrap()'s to do buffer switches
 * instead of setting up a fresh grecs_json_in.  A bit of a hack ...
 */
static int grecs_json__did_buffer_switch_on_eof;
/* %ok-for-header */

/* %endif */

void grecs_json_restart (FILE *input_file  );
void grecs_json__switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE grecs_json__create_buffer (FILE *file,int size  );
void grecs_json__delete_buffer (YY_BUFFER_STATE b  );
void grecs_json__flush_buffer (YY_BUFFER_STATE b  );
void grecs_json_push_buffer_state (YY_BUFFER_STATE new_buffer  );
void grecs_json_pop_buffer_state (void );

static void grecs_json_ensure_buffer_stack (void );
static void grecs_json__load_buffer_state (void );
static void grecs_json__init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER grecs_json__flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE grecs_json__scan_buffer (char *base,grecs_json__size_t size  );
YY_BUFFER_STATE grecs_json__scan_string (grecs_json_const char *grecs_json__str  );
YY_BUFFER_STATE grecs_json__scan_bytes (grecs_json_const char *bytes,grecs_json__size_t len  );

/* %endif */

void *grecs_json_alloc (grecs_json__size_t  );
void *grecs_json_realloc (void *,grecs_json__size_t  );
void grecs_json_free (void *  );

#define grecs_json__new_buffer grecs_json__create_buffer

#define grecs_json__set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        grecs_json_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            grecs_json__create_buffer(grecs_json_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->grecs_json__is_interactive = is_interactive; \
	}

#define grecs_json__set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        grecs_json_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            grecs_json__create_buffer(grecs_json_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->grecs_json__at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->grecs_json__at_bol)

/* %% [1.0] grecs_json_text/grecs_json_in/grecs_json_out/grecs_json__state_type/grecs_json_lineno etc. def's & init go here */

#define FLEX_DEBUG

typedef unsigned char YY_CHAR;

FILE *grecs_json_in = (FILE *) 0, *grecs_json_out = (FILE *) 0;

typedef int grecs_json__state_type;

extern int grecs_json_lineno;

int grecs_json_lineno = 1;

extern char *grecs_json_text;
#define grecs_json_text_ptr grecs_json_text

/* %if-c-only Standard (non-C++) definition */

static grecs_json__state_type grecs_json__get_previous_state (void );
static grecs_json__state_type grecs_json__try_NUL_trans (grecs_json__state_type current_state  );
static int grecs_json__get_next_buffer (void );
static void grecs_json__fatal_error (grecs_json_const char msg[]  );

/* %endif */

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up grecs_json_text.
 */
#define YY_DO_BEFORE_ACTION \
	(grecs_json_text_ptr) = grecs_json__bp; \
/* %% [2.0] code to fiddle grecs_json_text and grecs_json_leng for grecs_json_more() goes here \ */\
	grecs_json_leng = (size_t) (grecs_json__cp - grecs_json__bp); \
	(grecs_json__hold_char) = *grecs_json__cp; \
	*grecs_json__cp = '\0'; \
/* %% [3.0] code to copy grecs_json_text_ptr to grecs_json_text[] goes here, if %array \ */\
	(grecs_json__c_buf_p) = grecs_json__cp;

/* %% [4.0] data tables for the DFA and the user's section 1 definitions go here */
#define YY_NUM_RULES 15
#define YY_END_OF_BUFFER 16
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct grecs_json__trans_info
	{
	flex_int32_t grecs_json__verify;
	flex_int32_t grecs_json__nxt;
	};
static grecs_json_const flex_int16_t grecs_json__accept[61] =
    {   0,
       12,   12,    0,    0,   16,   14,   12,   13,   14,   11,
       14,    1,   14,   14,   14,   15,    5,   15,   12,    0,
        2,    0,    1,    0,    1,    0,    0,    0,    0,    0,
        5,    0,    7,    7,    4,    4,    1,    1,    0,    1,
        0,    0,    0,    0,    0,    1,    0,    1,    1,    1,
        0,    8,    9,    0,    0,    1,   10,    6,    3,    0
    } ;

static grecs_json_const flex_int32_t grecs_json__ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    4,    1,    1,    1,    1,    1,    1,
        1,    1,    5,    6,    7,    1,    1,    8,    8,    8,
        8,    8,    8,    8,    8,    8,    8,    9,    1,    1,
        1,    1,    1,    1,   10,   10,   10,   10,   11,   10,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
       12,   13,   14,    1,    1,    1,   15,   10,   10,   10,

       16,   17,    1,    1,    1,    1,    1,   18,    1,   19,
        1,    1,    1,   20,   21,   22,   23,    1,    1,    1,
        1,    1,   24,    1,   25,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static grecs_json_const flex_int32_t grecs_json__meta[26] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    3,    1,    3,
        3,    1,    1,    1,    3,    3,    3,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static grecs_json_const flex_int16_t grecs_json__base[73] =
    {   0,
        0,    0,   22,   23,  110,  131,  107,  131,   24,  131,
      100,   22,   83,   70,   72,   27,  131,   33,   80,   38,
      131,   44,   54,   73,   55,   67,   62,   59,   50,   43,
      131,   68,  131,    0,  131,    0,   78,   79,   61,   80,
       47,   49,   48,    0,    0,   89,   94,   95,   50,   96,
       41,  131,  131,    0,    0,   45,  131,  131,  131,  131,
      112,  115,  118,  121,  124,  127,   43,   42,   36,   31,
       29,   26
    } ;

static grecs_json_const flex_int16_t grecs_json__def[73] =
    {   0,
       60,    1,   61,   61,   60,   60,   60,   60,   62,   60,
       60,   63,   60,   60,   60,   64,   60,   65,   60,   62,
       60,   66,   63,   60,   63,   60,   60,   60,   60,   64,
       60,   65,   60,   67,   60,   68,   60,   63,   60,   60,
       60,   60,   60,   69,   70,   60,   60,   63,   60,   60,
       60,   60,   60,   71,   72,   60,   60,   60,   60,    0,
       60,   60,   60,   60,   60,   60,   60,   60,   60,   60,
       60,   60
    } ;

static grecs_json_const flex_int16_t grecs_json__nxt[157] =
    {   0,
        6,    7,    8,    9,    6,   10,   11,   12,   10,    6,
        6,   10,    6,   10,    6,    6,   13,    6,   14,    6,
        6,   15,    6,   10,   10,   17,   17,   21,   59,   25,
       31,   58,   26,   55,   18,   18,   22,   26,   54,   32,
       34,   21,   34,   34,   45,   44,   31,   34,   34,   34,
       22,   36,   56,   36,   36,   32,   57,   56,   36,   36,
       36,   25,   38,   53,   26,   26,   52,   51,   49,   26,
       26,   39,   43,   39,   40,   34,   42,   34,   34,   41,
       37,   19,   34,   34,   34,   46,   48,   50,   47,   26,
       47,   29,   28,   47,   26,   47,   46,   27,   39,   47,

       39,   49,   48,   50,   47,   26,   47,   23,   19,   60,
       26,   47,   16,   16,   16,   20,   20,   20,   24,   60,
       24,   30,   30,   30,   33,   60,   33,   35,   60,   35,
        5,   60,   60,   60,   60,   60,   60,   60,   60,   60,
       60,   60,   60,   60,   60,   60,   60,   60,   60,   60,
       60,   60,   60,   60,   60,   60
    } ;

static grecs_json_const flex_int16_t grecs_json__chk[157] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    3,    4,    9,   72,   12,
       16,   71,   12,   70,    3,    4,    9,   12,   69,   16,
       18,   20,   18,   18,   68,   67,   30,   18,   18,   18,
       20,   22,   56,   22,   22,   30,   51,   49,   22,   22,
       22,   23,   25,   43,   23,   25,   42,   41,   39,   23,
       25,   26,   29,   26,   26,   32,   28,   32,   32,   27,
       24,   19,   32,   32,   32,   37,   38,   40,   37,   38,
       40,   15,   14,   37,   38,   40,   46,   13,   47,   46,

       47,   47,   48,   50,   46,   48,   50,   11,    7,    5,
       48,   50,   61,   61,   61,   62,   62,   62,   63,    0,
       63,   64,   64,   64,   65,    0,   65,   66,    0,   66,
       60,   60,   60,   60,   60,   60,   60,   60,   60,   60,
       60,   60,   60,   60,   60,   60,   60,   60,   60,   60,
       60,   60,   60,   60,   60,   60
    } ;

static grecs_json__state_type grecs_json__last_accepting_state;
static char *grecs_json__last_accepting_cpos;

extern int grecs_json__flex_debug;
int grecs_json__flex_debug = 1;

static grecs_json_const flex_int16_t grecs_json__rule_linenum[15] =
    {   0,
      181,  185,  189,  194,  204,  209,  213,  222,  223,  224,
      225,  226,  227,  228
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define grecs_json_more() grecs_json_more_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *grecs_json_text;
#line 1 "json-lex.l"
#define YY_NO_INPUT 1

#line 9 "json-lex.l"
/* This file is part of Grecs.
   Copyright (C) 2012-2016 Sergey Poznyakoff.
 
   Grecs is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.
 
   Grecs is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with Grecs.  If not, see <http://www.gnu.org/licenses/>. */

#include "grecs.h"
#include "json-gram.h"
#include "grecs/json.h"

static char const *input_ptr;
static size_t input_size;
struct grecs_locus_point json_current_locus_point;   /* Input location */

char const *json_err_diag;
struct grecs_locus json_err_locus;

#undef YY_INPUT
#define YY_INPUT(buf,result,max_size)					\
	do {								\
		size_t n = (max_size > input_size) ? input_size : max_size; \
		if (n) {						\
			memcpy(buf, input_ptr, n);			\
			input_ptr += n;					\
			input_size -= n;				\
		}							\
		result = n;						\
	} while(0)

#define YY_USER_ACTION do {						\
		if (YYSTATE == 0) {					\
			grecs_json_lloc.beg = json_current_locus_point;		\
			grecs_json_lloc.beg.col++;				\
		}							\
  		json_current_locus_point.col += grecs_json_leng;			\
 		grecs_json_lloc.end = json_current_locus_point;			\
   	} while (0);

void
jsonlex_setup(char const *s, size_t l)
{
	input_ptr = s;
	input_size = l;
	json_current_locus_point.file = NULL;
	json_current_locus_point.line = 1;
	json_current_locus_point.col = 0;
	json_err_diag = NULL;
	grecs_json__flex_debug = 0;
}

void
jsonlex_diag(const char *s)
{
	if (!json_err_diag) {
		json_err_diag = s;
		json_err_locus = grecs_json_lloc;
	}
}
		
static int
utf8_wctomb(char *u)
{
	unsigned int wc = strtoul(u, NULL, 16);
	int count;
	char r[6];
	
	if (wc < 0x80)
		count = 1;
	else if (wc < 0x800)
		count = 2;
	else if (wc < 0x10000)
		count = 3;
	else if (wc < 0x200000)
		count = 4;
	else if (wc < 0x4000000)
		count = 5;
	else if (wc <= 0x7fffffff)
		count = 6;
	else
		return -1;

	switch (count) {
		/* Note: code falls through cases! */
	case 6:
		r[5] = 0x80 | (wc & 0x3f);
		wc = wc >> 6;
		wc |= 0x4000000;
	case 5:
		r[4] = 0x80 | (wc & 0x3f);
		wc = wc >> 6;
		wc |= 0x200000;
	case 4:
		r[3] = 0x80 | (wc & 0x3f);
		wc = wc >> 6;
		wc |= 0x10000;
	case 3:
		r[2] = 0x80 | (wc & 0x3f);
		wc = wc >> 6;
		wc |= 0x800;
	case 2:
		r[1] = 0x80 | (wc & 0x3f);
		wc = wc >> 6;
		wc |= 0xc0;
	case 1:
		r[0] = wc;
	}
	grecs_line_acc_grow(r, count);
	return count;
}

int
json_unescape(char c, char *o)
{
	static char transtab[] = "\\\\\"\"b\bf\fn\nr\rt\t";
	char *p;

	for (p = transtab; *p; p += 2) {
		if (p[0] == c) {
			*o = p[1];
			return 0;
		}
	}
	return -1;
}

#define YY_SKIP_YYWRAP 1
static int
grecs_json_wrap()
{
	return 1;
}

static struct grecs_txtacc *json_line_acc;

static void
json_line_begin()
{
	if (!json_line_acc)
		json_line_acc = grecs_txtacc_create();
}

static char *
json_line_finish()
{
	if (json_line_acc) {
		char nil = 0;
		grecs_txtacc_grow(json_line_acc, &nil, 1);
		return grecs_txtacc_finish(json_line_acc, 1);
	}
	return NULL;
}

static void
json_line_grow(char const *text, size_t len)	
{
	grecs_txtacc_grow(json_line_acc, text, len);
}	

#line 768 "json-lex.c"

#define INITIAL 0
#define STR 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
/* %if-c-only */
#include <unistd.h>
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* %if-c-only Reentrant structure and macros (non-C++). */
/* %if-reentrant */
/* %if-c-only */

static int grecs_json__init_globals (void );

/* %endif */
/* %if-reentrant */
/* %endif */
/* %endif End reentrant structures and macros. */

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int grecs_json_lex_destroy (void );

int grecs_json_get_debug (void );

void grecs_json_set_debug (int debug_flag  );

YY_EXTRA_TYPE grecs_json_get_extra (void );

void grecs_json_set_extra (YY_EXTRA_TYPE user_defined  );

FILE *grecs_json_get_in (void );

void grecs_json_set_in  (FILE * in_str  );

FILE *grecs_json_get_out (void );

void grecs_json_set_out  (FILE * out_str  );

grecs_json__size_t grecs_json_get_leng (void );

char *grecs_json_get_text (void );

int grecs_json_get_lineno (void );

void grecs_json_set_lineno (int line_number  );

/* %if-bison-bridge */
/* %endif */

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int grecs_json_wrap (void );
#else
extern int grecs_json_wrap (void );
#endif
#endif

/* %not-for-header */

/* %ok-for-header */

/* %endif */

#ifndef grecs_json_text_ptr
static void grecs_json__flex_strncpy (char *,grecs_json_const char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int grecs_json__flex_strlen (grecs_json_const char * );
#endif

#ifndef YY_NO_INPUT
/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */

#ifdef __cplusplus
static int grecs_json_input (void );
#else
static int input (void );
#endif
/* %ok-for-header */

/* %endif */
#endif

/* %if-c-only */

/* %endif */

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* %if-c-only Standard (non-C++) definition */
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( grecs_json_text, grecs_json_leng, 1, grecs_json_out )) {} } while (0)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
/* %% [5.0] fread()/read() definition of YY_INPUT goes here unless we're doing C++ \ */\
	if ( YY_CURRENT_BUFFER_LVALUE->grecs_json__is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( grecs_json_in )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( grecs_json_in ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, grecs_json_in))==0 && ferror(grecs_json_in)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(grecs_json_in); \
			} \
		}\
\
/* %if-c++-only C++ definition \ */\
/* %endif */

#endif

/* No semi-colon after return; correct usage is to write "grecs_json_terminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef grecs_json_terminate
#define grecs_json_terminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
/* %if-c-only */
#define YY_FATAL_ERROR(msg) grecs_json__fatal_error( msg )
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

/* %if-tables-serialization structures and prototypes */
/* %not-for-header */

/* %ok-for-header */

/* %not-for-header */

/* %tables-grecs_json_dmap generated elements */
/* %endif */
/* end tables serialization structures and prototypes */

/* %ok-for-header */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1
/* %if-c-only Standard (non-C++) definition */

extern int grecs_json_lex (void);

#define YY_DECL int grecs_json_lex (void)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after grecs_json_text and grecs_json_leng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

/* %% [6.0] YY_RULE_SETUP definition goes here */
#define YY_RULE_SETUP \
	YY_USER_ACTION

/* %not-for-header */

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register grecs_json__state_type grecs_json__current_state;
	register char *grecs_json__cp, *grecs_json__bp;
	register int grecs_json__act;
    
/* %% [7.0] user's declarations go here */
#line 180 "json-lex.l"

#line 1011 "json-lex.c"

	if ( !(grecs_json__init) )
		{
		(grecs_json__init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (grecs_json__start) )
			(grecs_json__start) = 1;	/* first start state */

		if ( ! grecs_json_in )
/* %if-c-only */
			grecs_json_in = stdin;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! grecs_json_out )
/* %if-c-only */
			grecs_json_out = stdout;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! YY_CURRENT_BUFFER ) {
			grecs_json_ensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				grecs_json__create_buffer(grecs_json_in,YY_BUF_SIZE );
		}

		grecs_json__load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
/* %% [8.0] grecs_json_more()-related code goes here */
		grecs_json__cp = (grecs_json__c_buf_p);

		/* Support of grecs_json_text. */
		*grecs_json__cp = (grecs_json__hold_char);

		/* grecs_json__bp points to the position in grecs_json__ch_buf of the start of
		 * the current run.
		 */
		grecs_json__bp = grecs_json__cp;

/* %% [9.0] code to set up and find next match goes here */
		grecs_json__current_state = (grecs_json__start);
grecs_json__match:
		do
			{
			register YY_CHAR grecs_json__c = grecs_json__ec[YY_SC_TO_UI(*grecs_json__cp)];
			if ( grecs_json__accept[grecs_json__current_state] )
				{
				(grecs_json__last_accepting_state) = grecs_json__current_state;
				(grecs_json__last_accepting_cpos) = grecs_json__cp;
				}
			while ( grecs_json__chk[grecs_json__base[grecs_json__current_state] + grecs_json__c] != grecs_json__current_state )
				{
				grecs_json__current_state = (int) grecs_json__def[grecs_json__current_state];
				if ( grecs_json__current_state >= 61 )
					grecs_json__c = grecs_json__meta[(unsigned int) grecs_json__c];
				}
			grecs_json__current_state = grecs_json__nxt[grecs_json__base[grecs_json__current_state] + (unsigned int) grecs_json__c];
			++grecs_json__cp;
			}
		while ( grecs_json__base[grecs_json__current_state] != 131 );

grecs_json__find_action:
/* %% [10.0] code to find the action number goes here */
		grecs_json__act = grecs_json__accept[grecs_json__current_state];
		if ( grecs_json__act == 0 )
			{ /* have to back up */
			grecs_json__cp = (grecs_json__last_accepting_cpos);
			grecs_json__current_state = (grecs_json__last_accepting_state);
			grecs_json__act = grecs_json__accept[grecs_json__current_state];
			}

		YY_DO_BEFORE_ACTION;

/* %% [11.0] code for grecs_json_lineno update goes here */

do_action:	/* This label is used only to access EOF actions. */

/* %% [12.0] debug code goes here */
		if ( grecs_json__flex_debug )
			{
			if ( grecs_json__act == 0 )
				fprintf( stderr, "--scanner backing up\n" );
			else if ( grecs_json__act < 15 )
				fprintf( stderr, "--accepting rule at line %ld (\"%s\")\n",
				         (long)grecs_json__rule_linenum[grecs_json__act], grecs_json_text );
			else if ( grecs_json__act == 15 )
				fprintf( stderr, "--accepting default rule (\"%s\")\n",
				         grecs_json_text );
			else if ( grecs_json__act == 16 )
				fprintf( stderr, "--(end of buffer or a NUL)\n" );
			else
				fprintf( stderr, "--EOF (start condition %d)\n", YY_START );
			}

		switch ( grecs_json__act )
	{ /* beginning of action switch */
/* %% [13.0] actions go here */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*grecs_json__cp = (grecs_json__hold_char);
			grecs_json__cp = (grecs_json__last_accepting_cpos);
			grecs_json__current_state = (grecs_json__last_accepting_state);
			goto grecs_json__find_action;

case 1:
YY_RULE_SETUP
#line 181 "json-lex.l"
{
	grecs_json_lval.n = strtod(grecs_json_text, NULL);
	return T_NUMBER;
      }
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 185 "json-lex.l"
{ json_line_begin();
                     json_line_grow(grecs_json_text + 1, grecs_json_leng - 2);
                     grecs_json_lval.s = json_line_finish();
                     return T_STRING; }
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 189 "json-lex.l"
{ BEGIN(STR);
                     json_line_begin();
                     json_line_grow(grecs_json_text + 1, grecs_json_leng - 5);
                     utf8_wctomb(grecs_json_text + grecs_json_leng - 4);
                   }
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 194 "json-lex.l"
{ char c;
                     BEGIN(STR);
                     json_line_begin();
                     json_line_grow(grecs_json_text + 1, grecs_json_leng - 3);
                     if (json_unescape(grecs_json_text[grecs_json_leng - 1], &c)) {
                             jsonlex_diag("invalid UTF-8 codepoint");
                             return T_ERR;
                     }
		     json_line_grow(&c, 1);
                   }
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 204 "json-lex.l"
{ BEGIN(INITIAL);
                        if (grecs_json_leng > 1)
				json_line_grow(grecs_json_text, grecs_json_leng - 1); 
                        grecs_json_lval.s = json_line_finish();
	                return T_STRING; }
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 209 "json-lex.l"
{
                     json_line_grow(grecs_json_text, grecs_json_leng - 5);
                     utf8_wctomb(grecs_json_text + grecs_json_leng - 4);
}
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 213 "json-lex.l"
{
                     char c;
                     json_line_grow(grecs_json_text, grecs_json_leng - 2);
                     if (json_unescape(grecs_json_text[grecs_json_leng - 1], &c)) {
                             jsonlex_diag("invalid UTF-8 codepoint");
                             return T_ERR;
                     }
                     json_line_grow(&c, 1); }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 222 "json-lex.l"
{ return T_NULL; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 223 "json-lex.l"
{ grecs_json_lval.b = 1; return T_BOOL; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 224 "json-lex.l"
{ grecs_json_lval.b = 0; return T_BOOL; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 225 "json-lex.l"
return grecs_json_text[0];
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 226 "json-lex.l"
;
	YY_BREAK
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 227 "json-lex.l"
grecs_locus_point_advance_line(json_current_locus_point);
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 228 "json-lex.l"
{ jsonlex_diag("bogus character");
            return T_ERR; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 230 "json-lex.l"
ECHO;
	YY_BREAK
#line 1241 "json-lex.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(STR):
	grecs_json_terminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int grecs_json__amount_of_matched_text = (int) (grecs_json__cp - (grecs_json_text_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*grecs_json__cp = (grecs_json__hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->grecs_json__buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed grecs_json_in at a new source and called
			 * grecs_json_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(grecs_json__n_chars) = YY_CURRENT_BUFFER_LVALUE->grecs_json__n_chars;
			YY_CURRENT_BUFFER_LVALUE->grecs_json__input_file = grecs_json_in;
			YY_CURRENT_BUFFER_LVALUE->grecs_json__buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for grecs_json__c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since grecs_json__c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (grecs_json__c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->grecs_json__ch_buf[(grecs_json__n_chars)] )
			{ /* This was really a NUL. */
			grecs_json__state_type grecs_json__next_state;

			(grecs_json__c_buf_p) = (grecs_json_text_ptr) + grecs_json__amount_of_matched_text;

			grecs_json__current_state = grecs_json__get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * grecs_json__get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			grecs_json__next_state = grecs_json__try_NUL_trans( grecs_json__current_state );

			grecs_json__bp = (grecs_json_text_ptr) + YY_MORE_ADJ;

			if ( grecs_json__next_state )
				{
				/* Consume the NUL. */
				grecs_json__cp = ++(grecs_json__c_buf_p);
				grecs_json__current_state = grecs_json__next_state;
				goto grecs_json__match;
				}

			else
				{
/* %% [14.0] code to do back-up for compressed tables and set up grecs_json__cp goes here */
				grecs_json__cp = (grecs_json__c_buf_p);
				goto grecs_json__find_action;
				}
			}

		else switch ( grecs_json__get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(grecs_json__did_buffer_switch_on_eof) = 0;

				if ( grecs_json_wrap( ) )
					{
					/* Note: because we've taken care in
					 * grecs_json__get_next_buffer() to have set up
					 * grecs_json_text, we can now set up
					 * grecs_json__c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(grecs_json__c_buf_p) = (grecs_json_text_ptr) + YY_MORE_ADJ;

					grecs_json__act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (grecs_json__did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(grecs_json__c_buf_p) =
					(grecs_json_text_ptr) + grecs_json__amount_of_matched_text;

				grecs_json__current_state = grecs_json__get_previous_state(  );

				grecs_json__cp = (grecs_json__c_buf_p);
				grecs_json__bp = (grecs_json_text_ptr) + YY_MORE_ADJ;
				goto grecs_json__match;

			case EOB_ACT_LAST_MATCH:
				(grecs_json__c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->grecs_json__ch_buf[(grecs_json__n_chars)];

				grecs_json__current_state = grecs_json__get_previous_state(  );

				grecs_json__cp = (grecs_json__c_buf_p);
				grecs_json__bp = (grecs_json_text_ptr) + YY_MORE_ADJ;
				goto grecs_json__find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of grecs_json_lex */
/* %ok-for-header */

/* %if-c++-only */
/* %not-for-header */

/* %ok-for-header */

/* %endif */

/* grecs_json__get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
/* %if-c-only */
static int grecs_json__get_next_buffer (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->grecs_json__ch_buf;
	register char *source = (grecs_json_text_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (grecs_json__c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->grecs_json__ch_buf[(grecs_json__n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->grecs_json__fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (grecs_json__c_buf_p) - (grecs_json_text_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((grecs_json__c_buf_p) - (grecs_json_text_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->grecs_json__buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->grecs_json__n_chars = (grecs_json__n_chars) = 0;

	else
		{
			grecs_json__size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->grecs_json__buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int grecs_json__c_buf_p_offset =
				(int) ((grecs_json__c_buf_p) - b->grecs_json__ch_buf);

			if ( b->grecs_json__is_our_buffer )
				{
				grecs_json__size_t new_size = b->grecs_json__buf_size * 2;

				if ( new_size <= 0 )
					b->grecs_json__buf_size += b->grecs_json__buf_size / 8;
				else
					b->grecs_json__buf_size *= 2;

				b->grecs_json__ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					grecs_json_realloc((void *) b->grecs_json__ch_buf,b->grecs_json__buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->grecs_json__ch_buf = 0;

			if ( ! b->grecs_json__ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(grecs_json__c_buf_p) = &b->grecs_json__ch_buf[grecs_json__c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->grecs_json__buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->grecs_json__ch_buf[number_to_move]),
			(grecs_json__n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->grecs_json__n_chars = (grecs_json__n_chars);
		}

	if ( (grecs_json__n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			grecs_json_restart(grecs_json_in  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->grecs_json__buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((grecs_json__size_t) ((grecs_json__n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->grecs_json__buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		grecs_json__size_t new_size = (grecs_json__n_chars) + number_to_move + ((grecs_json__n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->grecs_json__ch_buf = (char *) grecs_json_realloc((void *) YY_CURRENT_BUFFER_LVALUE->grecs_json__ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->grecs_json__ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in grecs_json__get_next_buffer()" );
	}

	(grecs_json__n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->grecs_json__ch_buf[(grecs_json__n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->grecs_json__ch_buf[(grecs_json__n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(grecs_json_text_ptr) = &YY_CURRENT_BUFFER_LVALUE->grecs_json__ch_buf[0];

	return ret_val;
}

/* grecs_json__get_previous_state - get the state just before the EOB char was reached */

/* %if-c-only */
/* %not-for-header */

    static grecs_json__state_type grecs_json__get_previous_state (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	register grecs_json__state_type grecs_json__current_state;
	register char *grecs_json__cp;
    
/* %% [15.0] code to get the start state into grecs_json__current_state goes here */
	grecs_json__current_state = (grecs_json__start);

	for ( grecs_json__cp = (grecs_json_text_ptr) + YY_MORE_ADJ; grecs_json__cp < (grecs_json__c_buf_p); ++grecs_json__cp )
		{
/* %% [16.0] code to find the next state goes here */
		register YY_CHAR grecs_json__c = (*grecs_json__cp ? grecs_json__ec[YY_SC_TO_UI(*grecs_json__cp)] : 1);
		if ( grecs_json__accept[grecs_json__current_state] )
			{
			(grecs_json__last_accepting_state) = grecs_json__current_state;
			(grecs_json__last_accepting_cpos) = grecs_json__cp;
			}
		while ( grecs_json__chk[grecs_json__base[grecs_json__current_state] + grecs_json__c] != grecs_json__current_state )
			{
			grecs_json__current_state = (int) grecs_json__def[grecs_json__current_state];
			if ( grecs_json__current_state >= 61 )
				grecs_json__c = grecs_json__meta[(unsigned int) grecs_json__c];
			}
		grecs_json__current_state = grecs_json__nxt[grecs_json__base[grecs_json__current_state] + (unsigned int) grecs_json__c];
		}

	return grecs_json__current_state;
}

/* grecs_json__try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = grecs_json__try_NUL_trans( current_state );
 */
/* %if-c-only */
    static grecs_json__state_type grecs_json__try_NUL_trans  (grecs_json__state_type grecs_json__current_state )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	register int grecs_json__is_jam;
    /* %% [17.0] code to find the next state, and perhaps do backing up, goes here */
	register char *grecs_json__cp = (grecs_json__c_buf_p);

	register YY_CHAR grecs_json__c = 1;
	if ( grecs_json__accept[grecs_json__current_state] )
		{
		(grecs_json__last_accepting_state) = grecs_json__current_state;
		(grecs_json__last_accepting_cpos) = grecs_json__cp;
		}
	while ( grecs_json__chk[grecs_json__base[grecs_json__current_state] + grecs_json__c] != grecs_json__current_state )
		{
		grecs_json__current_state = (int) grecs_json__def[grecs_json__current_state];
		if ( grecs_json__current_state >= 61 )
			grecs_json__c = grecs_json__meta[(unsigned int) grecs_json__c];
		}
	grecs_json__current_state = grecs_json__nxt[grecs_json__base[grecs_json__current_state] + (unsigned int) grecs_json__c];
	grecs_json__is_jam = (grecs_json__current_state == 60);

		return grecs_json__is_jam ? 0 : grecs_json__current_state;
}

/* %if-c-only */

/* %endif */

/* %if-c-only */
#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int grecs_json_input (void)
#else
    static int input  (void)
#endif

/* %endif */
/* %if-c++-only */
/* %endif */
{
	int c;
    
	*(grecs_json__c_buf_p) = (grecs_json__hold_char);

	if ( *(grecs_json__c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* grecs_json__c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (grecs_json__c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->grecs_json__ch_buf[(grecs_json__n_chars)] )
			/* This was really a NUL. */
			*(grecs_json__c_buf_p) = '\0';

		else
			{ /* need more input */
			grecs_json__size_t offset = (grecs_json__c_buf_p) - (grecs_json_text_ptr);
			++(grecs_json__c_buf_p);

			switch ( grecs_json__get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because grecs_json__g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					grecs_json_restart(grecs_json_in );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( grecs_json_wrap( ) )
						return EOF;

					if ( ! (grecs_json__did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return grecs_json_input();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(grecs_json__c_buf_p) = (grecs_json_text_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (grecs_json__c_buf_p);	/* cast for 8-bit char's */
	*(grecs_json__c_buf_p) = '\0';	/* preserve grecs_json_text */
	(grecs_json__hold_char) = *++(grecs_json__c_buf_p);

/* %% [19.0] update BOL and grecs_json_lineno */

	return c;
}
/* %if-c-only */
#endif	/* ifndef YY_NO_INPUT */
/* %endif */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
/* %if-c-only */
    void grecs_json_restart  (FILE * input_file )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	if ( ! YY_CURRENT_BUFFER ){
        grecs_json_ensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            grecs_json__create_buffer(grecs_json_in,YY_BUF_SIZE );
	}

	grecs_json__init_buffer(YY_CURRENT_BUFFER,input_file );
	grecs_json__load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
/* %if-c-only */
    void grecs_json__switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		grecs_json_pop_buffer_state();
	 *		grecs_json_push_buffer_state(new_buffer);
     */
	grecs_json_ensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(grecs_json__c_buf_p) = (grecs_json__hold_char);
		YY_CURRENT_BUFFER_LVALUE->grecs_json__buf_pos = (grecs_json__c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->grecs_json__n_chars = (grecs_json__n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	grecs_json__load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (grecs_json_wrap()) processing, but the only time this flag
	 * is looked at is after grecs_json_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(grecs_json__did_buffer_switch_on_eof) = 1;
}

/* %if-c-only */
static void grecs_json__load_buffer_state  (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	(grecs_json__n_chars) = YY_CURRENT_BUFFER_LVALUE->grecs_json__n_chars;
	(grecs_json_text_ptr) = (grecs_json__c_buf_p) = YY_CURRENT_BUFFER_LVALUE->grecs_json__buf_pos;
	grecs_json_in = YY_CURRENT_BUFFER_LVALUE->grecs_json__input_file;
	(grecs_json__hold_char) = *(grecs_json__c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
/* %if-c-only */
    YY_BUFFER_STATE grecs_json__create_buffer  (FILE * file, int  size )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) grecs_json_alloc(sizeof( struct grecs_json__buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in grecs_json__create_buffer()" );

	b->grecs_json__buf_size = size;

	/* grecs_json__ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->grecs_json__ch_buf = (char *) grecs_json_alloc(b->grecs_json__buf_size + 2  );
	if ( ! b->grecs_json__ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in grecs_json__create_buffer()" );

	b->grecs_json__is_our_buffer = 1;

	grecs_json__init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with grecs_json__create_buffer()
 * 
 */
/* %if-c-only */
    void grecs_json__delete_buffer (YY_BUFFER_STATE  b )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->grecs_json__is_our_buffer )
		grecs_json_free((void *) b->grecs_json__ch_buf  );

	grecs_json_free((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a grecs_json_restart() or at EOF.
 */
/* %if-c-only */
    static void grecs_json__init_buffer  (YY_BUFFER_STATE  b, FILE * file )
/* %endif */
/* %if-c++-only */
/* %endif */

{
	int oerrno = errno;
    
	grecs_json__flush_buffer(b );

	b->grecs_json__input_file = file;
	b->grecs_json__fill_buffer = 1;

    /* If b is the current buffer, then grecs_json__init_buffer was _probably_
     * called from grecs_json_restart() or through grecs_json__get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->grecs_json__bs_lineno = 1;
        b->grecs_json__bs_column = 0;
    }

/* %if-c-only */

        b->grecs_json__is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
/* %endif */
/* %if-c++-only */
/* %endif */
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
/* %if-c-only */
    void grecs_json__flush_buffer (YY_BUFFER_STATE  b )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if ( ! b )
		return;

	b->grecs_json__n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->grecs_json__ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->grecs_json__ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->grecs_json__buf_pos = &b->grecs_json__ch_buf[0];

	b->grecs_json__at_bol = 1;
	b->grecs_json__buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		grecs_json__load_buffer_state( );
}

/* %if-c-or-c++ */
/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
/* %if-c-only */
void grecs_json_push_buffer_state (YY_BUFFER_STATE new_buffer )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if (new_buffer == NULL)
		return;

	grecs_json_ensure_buffer_stack();

	/* This block is copied from grecs_json__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(grecs_json__c_buf_p) = (grecs_json__hold_char);
		YY_CURRENT_BUFFER_LVALUE->grecs_json__buf_pos = (grecs_json__c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->grecs_json__n_chars = (grecs_json__n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(grecs_json__buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from grecs_json__switch_to_buffer. */
	grecs_json__load_buffer_state( );
	(grecs_json__did_buffer_switch_on_eof) = 1;
}
/* %endif */

/* %if-c-or-c++ */
/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
/* %if-c-only */
void grecs_json_pop_buffer_state (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if (!YY_CURRENT_BUFFER)
		return;

	grecs_json__delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((grecs_json__buffer_stack_top) > 0)
		--(grecs_json__buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		grecs_json__load_buffer_state( );
		(grecs_json__did_buffer_switch_on_eof) = 1;
	}
}
/* %endif */

/* %if-c-or-c++ */
/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
/* %if-c-only */
static void grecs_json_ensure_buffer_stack (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	grecs_json__size_t num_to_alloc;
    
	if (!(grecs_json__buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(grecs_json__buffer_stack) = (struct grecs_json__buffer_state**)grecs_json_alloc
								(num_to_alloc * sizeof(struct grecs_json__buffer_state*)
								);
		if ( ! (grecs_json__buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in grecs_json_ensure_buffer_stack()" );
								  
		memset((grecs_json__buffer_stack), 0, num_to_alloc * sizeof(struct grecs_json__buffer_state*));
				
		(grecs_json__buffer_stack_max) = num_to_alloc;
		(grecs_json__buffer_stack_top) = 0;
		return;
	}

	if ((grecs_json__buffer_stack_top) >= ((grecs_json__buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (grecs_json__buffer_stack_max) + grow_size;
		(grecs_json__buffer_stack) = (struct grecs_json__buffer_state**)grecs_json_realloc
								((grecs_json__buffer_stack),
								num_to_alloc * sizeof(struct grecs_json__buffer_state*)
								);
		if ( ! (grecs_json__buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in grecs_json_ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((grecs_json__buffer_stack) + (grecs_json__buffer_stack_max), 0, grow_size * sizeof(struct grecs_json__buffer_state*));
		(grecs_json__buffer_stack_max) = num_to_alloc;
	}
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE grecs_json__scan_buffer  (char * base, grecs_json__size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) grecs_json_alloc(sizeof( struct grecs_json__buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in grecs_json__scan_buffer()" );

	b->grecs_json__buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->grecs_json__buf_pos = b->grecs_json__ch_buf = base;
	b->grecs_json__is_our_buffer = 0;
	b->grecs_json__input_file = 0;
	b->grecs_json__n_chars = b->grecs_json__buf_size;
	b->grecs_json__is_interactive = 0;
	b->grecs_json__at_bol = 1;
	b->grecs_json__fill_buffer = 0;
	b->grecs_json__buffer_status = YY_BUFFER_NEW;

	grecs_json__switch_to_buffer(b  );

	return b;
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan a string. The next call to grecs_json_lex() will
 * scan from a @e copy of @a str.
 * @param grecs_json_str a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       grecs_json__scan_bytes() instead.
 */
YY_BUFFER_STATE grecs_json__scan_string (grecs_json_const char * grecs_json_str )
{
    
	return grecs_json__scan_bytes(grecs_json_str,strlen(grecs_json_str) );
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan the given bytes. The next call to grecs_json_lex() will
 * scan from a @e copy of @a bytes.
 * @param grecs_json_bytes the byte buffer to scan
 * @param _grecs_json_bytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE grecs_json__scan_bytes  (grecs_json_const char * grecs_json_bytes, grecs_json__size_t  _grecs_json_bytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	grecs_json__size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _grecs_json_bytes_len + 2;
	buf = (char *) grecs_json_alloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in grecs_json__scan_bytes()" );

	for ( i = 0; i < _grecs_json_bytes_len; ++i )
		buf[i] = grecs_json_bytes[i];

	buf[_grecs_json_bytes_len] = buf[_grecs_json_bytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = grecs_json__scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in grecs_json__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->grecs_json__is_our_buffer = 1;

	return b;
}
/* %endif */

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

/* %if-c-only */
static void grecs_json__fatal_error (grecs_json_const char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}
/* %endif */
/* %if-c++-only */
/* %endif */

/* Redefine grecs_json_less() so it works in section 3 code. */

#undef grecs_json_less
#define grecs_json_less(n) \
	do \
		{ \
		/* Undo effects of setting up grecs_json_text. */ \
        int grecs_json_less_macro_arg = (n); \
        YY_LESS_LINENO(grecs_json_less_macro_arg);\
		grecs_json_text[grecs_json_leng] = (grecs_json__hold_char); \
		(grecs_json__c_buf_p) = grecs_json_text + grecs_json_less_macro_arg; \
		(grecs_json__hold_char) = *(grecs_json__c_buf_p); \
		*(grecs_json__c_buf_p) = '\0'; \
		grecs_json_leng = grecs_json_less_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/* %if-c-only */
/* %if-reentrant */
/* %endif */

/** Get the current line number.
 * 
 */
int grecs_json_get_lineno  (void)
{
        
    return grecs_json_lineno;
}

/** Get the input stream.
 * 
 */
FILE *grecs_json_get_in  (void)
{
        return grecs_json_in;
}

/** Get the output stream.
 * 
 */
FILE *grecs_json_get_out  (void)
{
        return grecs_json_out;
}

/** Get the length of the current token.
 * 
 */
grecs_json__size_t grecs_json_get_leng  (void)
{
        return grecs_json_leng;
}

/** Get the current token.
 * 
 */

char *grecs_json_get_text  (void)
{
        return grecs_json_text;
}

/* %if-reentrant */
/* %endif */

/** Set the current line number.
 * @param line_number
 * 
 */
void grecs_json_set_lineno (int  line_number )
{
    
    grecs_json_lineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see grecs_json__switch_to_buffer
 */
void grecs_json_set_in (FILE *  in_str )
{
        grecs_json_in = in_str ;
}

void grecs_json_set_out (FILE *  out_str )
{
        grecs_json_out = out_str ;
}

int grecs_json_get_debug  (void)
{
        return grecs_json__flex_debug;
}

void grecs_json_set_debug (int  bdebug )
{
        grecs_json__flex_debug = bdebug ;
}

/* %endif */

/* %if-reentrant */
/* %if-bison-bridge */
/* %endif */
/* %endif if-c-only */

/* %if-c-only */
static int grecs_json__init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from grecs_json_lex_destroy(), so don't allocate here.
     */

    (grecs_json__buffer_stack) = 0;
    (grecs_json__buffer_stack_top) = 0;
    (grecs_json__buffer_stack_max) = 0;
    (grecs_json__c_buf_p) = (char *) 0;
    (grecs_json__init) = 0;
    (grecs_json__start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    grecs_json_in = stdin;
    grecs_json_out = stdout;
#else
    grecs_json_in = (FILE *) 0;
    grecs_json_out = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * grecs_json_lex_init()
     */
    return 0;
}
/* %endif */

/* %if-c-only SNIP! this currently causes conflicts with the c++ scanner */
/* grecs_json_lex_destroy is for both reentrant and non-reentrant scanners. */
int grecs_json_lex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		grecs_json__delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		grecs_json_pop_buffer_state();
	}

	/* Destroy the stack itself. */
	grecs_json_free((grecs_json__buffer_stack) );
	(grecs_json__buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * grecs_json_lex() is called, initialization will occur. */
    grecs_json__init_globals( );

/* %if-reentrant */
/* %endif */
    return 0;
}
/* %endif */

/*
 * Internal utility routines.
 */

#ifndef grecs_json_text_ptr
static void grecs_json__flex_strncpy (char* s1, grecs_json_const char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int grecs_json__flex_strlen (grecs_json_const char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *grecs_json_alloc (grecs_json__size_t  size )
{
	return (void *) malloc( size );
}

void *grecs_json_realloc  (void * ptr, grecs_json__size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void grecs_json_free (void * ptr )
{
	free( (char *) ptr );	/* see grecs_json_realloc() for (char *) cast */
}

/* %if-tables-serialization definitions */
/* %define-grecs_json_tables   The name for this specific scanner's tables. */
#define YYTABLES_NAME "grecs_json_tables"
/* %endif */

/* %ok-for-header */

#line 230 "json-lex.l"
